@@ -1,6 +1,5 @@
 #!/usr/bin/env python
 
-# flake8: noqa
 
 import pkg_resources
 
@@ -49,6 +48,7 @@ from .camera.moving_camera import *
 from .camera.multi_camera import *
 from .camera.three_d_camera import *
 from .constants import *
+from .mobject.boolean_ops import *
 from .mobject.changing import *
 from .mobject.coordinate_systems import *
 from .mobject.frame import *
