@@ -245,6 +245,7 @@ class ManimConfig(MutableMapping):
         "custom_folders",
         "disable_caching",
         "disable_caching_warning",
+        "enable_wireframe",
         "ffmpeg_loglevel",
         "format",
         "flush_cache",
@@ -296,6 +297,7 @@ class ManimConfig(MutableMapping):
         "write_all",
         "write_to_movie",
         "zero_pad",
+        "force_window",
     }
 
     def __init__(self) -> None:
@@ -445,18 +447,18 @@ class ManimConfig(MutableMapping):
             self._d[key] = val
         else:
             raise ValueError(
-                f"{key} must be an integer such that {lo} <= {key} <= {hi}"
+                f"{key} must be an integer such that {lo} <= {key} <= {hi}",
             )
 
     def _set_pos_number(self, key: str, val: int, allow_inf: bool) -> None:
         """Set ``key`` to ``val`` if ``val`` is a positive integer."""
         if isinstance(val, int) and val > -1:
             self._d[key] = val
-        elif allow_inf and (val == -1 or val == float("inf")):
+        elif allow_inf and val in [-1, float("inf")]:
             self._d[key] = float("inf")
         else:
             raise ValueError(
-                f"{key} must be a non-negative integer (use -1 for infinity)"
+                f"{key} must be a non-negative integer (use -1 for infinity)",
             )
 
     def __repr__(self) -> str:
@@ -539,6 +541,8 @@ class ManimConfig(MutableMapping):
             "fullscreen",
             "use_projection_fill_shaders",
             "use_projection_stroke_shaders",
+            "enable_wireframe",
+            "force_window",
         ]:
             setattr(self, key, parser["CLI"].getboolean(key, fallback=False))
 
@@ -687,6 +691,8 @@ class ManimConfig(MutableMapping):
             "use_projection_fill_shaders",
             "use_projection_stroke_shaders",
             "zero_pad",
+            "enable_wireframe",
+            "force_window",
         ]:
             if hasattr(args, key):
                 attr = getattr(args, key)
@@ -696,9 +702,8 @@ class ManimConfig(MutableMapping):
                     self[key] = attr
 
         # dry_run is special because it can only be set to True
-        if hasattr(args, "dry_run"):
-            if getattr(args, "dry_run"):
-                self["dry_run"] = True
+        if getattr(args, "dry_run", False):
+            self["dry_run"] = True
 
         for key in [
             "media_dir",  # always set this one first
@@ -723,7 +728,7 @@ class ManimConfig(MutableMapping):
                 self.upto_animation_number = nflag[1]
             except Exception:
                 logging.getLogger("manim").info(
-                    f"No end scene number specified in -n option. Rendering from {nflag[0]} onwards..."
+                    f"No end scene number specified in -n option. Rendering from {nflag[0]} onwards...",
                 )
 
         # Handle the quality flags
@@ -759,10 +764,9 @@ class ManimConfig(MutableMapping):
         if args.tex_template:
             self.tex_template = TexTemplateFromFile(tex_filename=args.tex_template)
 
-        if self.renderer == "opengl":
-            if getattr(args, "write_to_movie") is None:
-                # --write_to_movie was not passed on the command line, so don't generate video.
-                self["write_to_movie"] = False
+        if self.renderer == "opengl" and getattr(args, "write_to_movie") is None:
+            # --write_to_movie was not passed on the command line, so don't generate video.
+            self["write_to_movie"] = False
 
         # Handle --gui_location flag.
         if getattr(args, "gui_location") is not None:
@@ -827,7 +831,9 @@ class ManimConfig(MutableMapping):
     progress_bar = property(
         lambda self: self._d["progress_bar"],
         lambda self, val: self._set_from_list(
-            "progress_bar", val, ["none", "display", "leave"]
+            "progress_bar",
+            val,
+            ["none", "display", "leave"],
         ),
         doc="Whether to show progress bars while rendering animations.",
     )
@@ -882,6 +888,18 @@ class ManimConfig(MutableMapping):
         doc="Whether to save the rendered scene in .gif format (-i).",
     )
 
+    enable_wireframe = property(
+        lambda self: self._d["enable_wireframe"],
+        lambda self, val: self._set_boolean("enable_wireframe", val),
+        doc="Enable wireframe debugging mode in opengl.",
+    )
+
+    force_window = property(
+        lambda self: self._d["force_window"],
+        lambda self, val: self._set_boolean("force_window", val),
+        doc="Set to force window when using the opengl renderer",
+    )
+
     @property
     def verbosity(self):
         """Logger verbosity; "DEBUG", "INFO", "WARNING", "ERROR", or "CRITICAL" (-v)."""
@@ -912,13 +930,15 @@ class ManimConfig(MutableMapping):
         )
         if self.format == "webm":
             logging.getLogger("manim").warning(
-                "Output format set as webm, this can be slower than other formats"
+                "Output format set as webm, this can be slower than other formats",
             )
 
     ffmpeg_loglevel = property(
         lambda self: self._d["ffmpeg_loglevel"],
         lambda self, val: self._set_from_list(
-            "ffmpeg_loglevel", val, ["DEBUG", "INFO", "WARNING", "ERROR", "CRITICAL"]
+            "ffmpeg_loglevel",
+            val,
+            ["DEBUG", "INFO", "WARNING", "ERROR", "CRITICAL"],
         ),
         doc="Verbosity level of ffmpeg (no flag).",
     )
@@ -1052,7 +1072,9 @@ class ManimConfig(MutableMapping):
     movie_file_extension = property(
         lambda self: self._d["movie_file_extension"],
         lambda self, val: self._set_from_list(
-            "movie_file_extension", val, [".mp4", ".mov", ".webm"]
+            "movie_file_extension",
+            val,
+            [".mp4", ".mov", ".webm"],
         ),
         doc="Either .mp4, .webm or .mov.",
     )
@@ -1080,8 +1102,7 @@ class ManimConfig(MutableMapping):
         for qual in constants.QUALITIES:
             if all([q[k] == constants.QUALITIES[qual][k] for k in keys]):
                 return qual
-        else:
-            return None
+        return None
 
     @quality.setter
     def quality(self, qual: str) -> None:
@@ -1108,8 +1129,7 @@ class ManimConfig(MutableMapping):
             self.write_to_movie is False
             and self.write_all is False
             and self.save_last_frame is False
-            and self.save_pngs is False
-            and self.save_as_gif is False
+            and not self.format
         )
 
     @dry_run.setter
@@ -1118,14 +1138,13 @@ class ManimConfig(MutableMapping):
             self.write_to_movie = False
             self.write_all = False
             self.save_last_frame = False
-            self.save_pngs = False
-            self.save_as_gif = False
+            self.format = None
         else:
             raise ValueError(
                 "It is unclear what it means to set dry_run to "
                 "False.  Instead, try setting each option "
                 "individually. (write_to_movie, write_all, "
-                "save_last_frame, save_pngs, or save_as_gif)"
+                "save_last_frame, save_pngs, or save_as_gif)",
             )
 
     @property
@@ -1401,7 +1420,7 @@ class ManimConfig(MutableMapping):
             raise KeyError(
                 "must pass one of "
                 "{media,video,images,text,tex,log}_dir "
-                "or {input,output}_file"
+                "or {input,output}_file",
             )
 
         dirs.remove(key)  # a path cannot contain itself
@@ -1418,7 +1437,7 @@ class ManimConfig(MutableMapping):
                 raise KeyError(
                     f"{key} {self._d[key]} requires the following "
                     + "keyword arguments: "
-                    + " ".join(exc.args)
+                    + " ".join(exc.args),
                 ) from exc
         return Path(path) if path else None
 
@@ -1520,7 +1539,7 @@ class ManimConfig(MutableMapping):
         if val:
             if not os.access(val, os.R_OK):
                 logging.getLogger("manim").warning(
-                    f"Custom TeX template {val} not found or not readable."
+                    f"Custom TeX template {val} not found or not readable.",
                 )
             else:
                 self._d["tex_template_file"] = Path(val)
