@@ -121,7 +121,10 @@ class ShowPartial(Animation):
         super().__init__(mobject, **kwargs)
 
     def interpolate_submobject(
-        self, submobject: Mobject, starting_submobject: Mobject, alpha: float
+        self,
+        submobject: Mobject,
+        starting_submobject: Mobject,
+        alpha: float,
     ) -> None:
         submobject.pointwise_become_partial(
             starting_submobject, *self._get_bounds(alpha)
@@ -254,7 +257,11 @@ class DrawBorderThenFill(Animation):
         return [*super().get_all_mobjects(), self.outline]
 
     def interpolate_submobject(
-        self, submobject: Mobject, starting_submobject: Mobject, outline, alpha: float
+        self,
+        submobject: Mobject,
+        starting_submobject: Mobject,
+        outline,
+        alpha: float,
     ) -> None:  # Fixme: not matching the parent class? What is outline doing here?
         index: int
         subalpha: int
@@ -294,7 +301,9 @@ class Write(DrawBorderThenFill):
         run_time: Optional[float] = kwargs.pop("run_time", None)
         lag_ratio: Optional[float] = kwargs.pop("lag_ratio", None)
         run_time, lag_ratio = self._set_default_config_from_length(
-            vmobject, run_time, lag_ratio
+            vmobject,
+            run_time,
+            lag_ratio,
         )
         self.reverse = reverse
         super().__init__(
@@ -374,7 +383,9 @@ class Unwrite(Write):
         run_time: Optional[float] = kwargs.pop("run_time", None)
         lag_ratio: Optional[float] = kwargs.pop("lag_ratio", None)
         run_time, lag_ratio = self._set_default_config_from_length(
-            vmobject, run_time, lag_ratio
+            vmobject,
+            run_time,
+            lag_ratio,
         )
         super().__init__(
             vmobject,
