@@ -17,6 +17,7 @@ from ..mobject.three_d_utils import (
 from ..mobject.types.point_cloud_mobject import Point
 from ..mobject.value_tracker import ValueTracker
 from ..utils.color import get_shaded_rgb
+from ..utils.deprecation import deprecated
 from ..utils.family import extract_mobject_family_members
 from ..utils.space_ops import rotation_about_z, rotation_matrix
 
@@ -24,7 +25,7 @@ from ..utils.space_ops import rotation_about_z, rotation_matrix
 class ThreeDCamera(Camera):
     def __init__(
         self,
-        distance=20.0,
+        focal_distance=20.0,
         shading_factor=0.2,
         default_distance=5.0,
         light_source_start_point=9 * DOWN + 7 * LEFT + 10 * OUT,
@@ -47,7 +48,7 @@ class ThreeDCamera(Camera):
         """
         self._frame_center = Point(kwargs.get("frame_center", ORIGIN), stroke_width=0)
         super().__init__(**kwargs)
-        self.distance = distance
+        self.focal_distance = focal_distance
         self.phi = phi
         self.theta = theta
         self.gamma = gamma
@@ -61,7 +62,7 @@ class ThreeDCamera(Camera):
         self.max_allowable_norm = 3 * config["frame_width"]
         self.phi_tracker = ValueTracker(self.phi)
         self.theta_tracker = ValueTracker(self.theta)
-        self.distance_tracker = ValueTracker(self.distance)
+        self.focal_distance_tracker = ValueTracker(self.focal_distance)
         self.gamma_tracker = ValueTracker(self.gamma)
         self.zoom_tracker = ValueTracker(self.zoom)
         self.fixed_orientation_mobjects = {}
@@ -78,10 +79,10 @@ class ThreeDCamera(Camera):
 
     def capture_mobjects(self, mobjects, **kwargs):
         self.reset_rotation_matrix()
-        Camera.capture_mobjects(self, mobjects, **kwargs)
+        super().capture_mobjects(mobjects, **kwargs)
 
     def get_value_trackers(self):
-        """Returns list of ValueTrackers of phi, theta, distance and gamma
+        """Returns list of ValueTrackers of phi, theta, focal_distance and gamma
 
         Returns
         -------
@@ -91,7 +92,7 @@ class ThreeDCamera(Camera):
         return [
             self.phi_tracker,
             self.theta_tracker,
-            self.distance_tracker,
+            self.focal_distance_tracker,
             self.gamma_tracker,
             self.zoom_tracker,
         ]
@@ -121,7 +122,9 @@ class ThreeDCamera(Camera):
         return rgbas
 
     def get_stroke_rgbas(
-        self, vmobject, background=False
+        self,
+        vmobject,
+        background=False,
     ):  # NOTE : DocStrings From parent
         return self.modified_rgbas(vmobject, vmobject.get_stroke_rgbas(background))
 
@@ -129,7 +132,7 @@ class ThreeDCamera(Camera):
         return self.modified_rgbas(vmobject, vmobject.get_fill_rgbas())
 
     def get_mobjects_to_display(self, *args, **kwargs):  # NOTE : DocStrings From parent
-        mobjects = Camera.get_mobjects_to_display(self, *args, **kwargs)
+        mobjects = super().get_mobjects_to_display(*args, **kwargs)
         rot_matrix = self.get_rotation_matrix()
 
         def z_key(mob):
@@ -161,15 +164,23 @@ class ThreeDCamera(Camera):
         """
         return self.theta_tracker.get_value()
 
+    @deprecated(
+        since="v0.11.0",
+        until="v0.12.0",
+        message="use focal_distance instead.",
+    )
     def get_distance(self):
-        """Returns radial distance from ORIGIN.
+        return self.get_focal_distance()
+
+    def get_focal_distance(self):
+        """Returns focal_distance of the Camera.
 
         Returns
         -------
         float
-            The radial distance from ORIGIN in MUnits.
+            The focal_distance of the Camera in MUnits.
         """
-        return self.distance_tracker.get_value()
+        return self.focal_distance_tracker.get_value()
 
     def get_gamma(self):
         """Returns the rotation of the camera about the vector from the ORIGIN to the Camera.
@@ -212,15 +223,23 @@ class ThreeDCamera(Camera):
         """
         self.theta_tracker.set_value(value)
 
+    @deprecated(
+        since="v0.11.0",
+        until="v0.12.0",
+        message="use focal_distance instead.",
+    )
     def set_distance(self, value):
-        """Sets the radial distance between the camera and ORIGIN.
+        return self.set_focal_distance(value)
+
+    def set_focal_distance(self, value):
+        """Sets the focal_distance of the Camera.
 
         Parameters
         ----------
         value : int, float
-            The new radial distance.
+            The focal_distance of the Camera.
         """
-        self.distance_tracker.set_value(value)
+        self.focal_distance_tracker.set_value(value)
 
     def set_gamma(self, value):
         """Sets the angle of rotation of the camera about the vector from the ORIGIN to the Camera.
@@ -294,7 +313,7 @@ class ThreeDCamera(Camera):
             The points after projecting.
         """
         frame_center = self.frame_center
-        distance = self.get_distance()
+        focal_distance = self.get_focal_distance()
         zoom = self.get_zoom()
         rot_matrix = self.get_rotation_matrix()
 
@@ -307,12 +326,12 @@ class ThreeDCamera(Camera):
                 # x and y by d / (d-z).  But for points with high
                 # z value that causes weird artifacts, and applying
                 # the exponential helps smooth it out.
-                factor = np.exp(zs / distance)
+                factor = np.exp(zs / focal_distance)
                 lt0 = zs < 0
-                factor[lt0] = distance / (distance - zs[lt0])
+                factor[lt0] = focal_distance / (focal_distance - zs[lt0])
             else:
-                factor = distance / (distance - zs)
-                factor[(distance - zs) < 0] = 10 ** 6
+                factor = focal_distance / (focal_distance - zs)
+                factor[(focal_distance - zs) < 0] = 10 ** 6
             points[:, i] *= factor * zoom
         return points
 
@@ -333,7 +352,9 @@ class ThreeDCamera(Camera):
         return self.project_points(point.reshape((1, 3)))[0, :]
 
     def transform_points_pre_display(
-        self, mobject, points
+        self,
+        mobject,
+        points,
     ):  # TODO: Write Docstrings for this Method.
         points = super().transform_points_pre_display(mobject, points)
         fixed_orientation = mobject in self.fixed_orientation_mobjects
