@@ -21,19 +21,26 @@ from manim.mobject.opengl_compatibility import ConvertToOpenGL
 
 from .. import config
 from ..constants import *
-from ..mobject.functions import ParametricFunction
+from ..mobject.functions import ImplicitFunction, ParametricFunction
 from ..mobject.geometry import (
     Arrow,
     Circle,
     DashedLine,
     Dot,
     Line,
+    Polygon,
     Rectangle,
     RegularPolygon,
 )
 from ..mobject.number_line import NumberLine
 from ..mobject.svg.tex_mobject import MathTex
-from ..mobject.types.vectorized_mobject import Mobject, VDict, VectorizedPoint, VGroup
+from ..mobject.types.vectorized_mobject import (
+    Mobject,
+    VDict,
+    VectorizedPoint,
+    VGroup,
+    VMobject,
+)
 from ..utils.color import (
     BLACK,
     BLUE,
@@ -193,7 +200,7 @@ class CoordinateSystem:
         return self.get_x_axis().get_unit_size()
 
     def get_y_unit_size(self):
-        return self.get_x_axis().get_unit_size()
+        return self.get_y_axis().get_unit_size()
 
     def get_x_axis_label(
         self,
@@ -302,11 +309,7 @@ class CoordinateSystem:
             The label.
         """
 
-        if (
-            isinstance(label_tex, float)
-            or isinstance(label_tex, int)
-            or isinstance(label_tex, str)
-        ):
+        if isinstance(label_tex, (float, int, str)):
             label_tex = MathTex(label_tex)
         return label_tex
 
@@ -393,7 +396,8 @@ class CoordinateSystem:
     def add_coordinates(
         self,
         *axes_numbers: Union[
-            Optional[Iterable[float]], Union[Dict[float, Union[str, float, "Mobject"]]]
+            Optional[Iterable[float]],
+            Union[Dict[float, Union[str, float, "Mobject"]]],
         ],
         **kwargs,
     ):
@@ -694,6 +698,54 @@ class CoordinateSystem:
         graph.underlying_function = function
         return graph
 
+    def get_implicit_curve(
+        self,
+        func: Callable,
+        min_depth: int = 5,
+        max_quads: int = 1500,
+        **kwargs,
+    ) -> ImplicitFunction:
+        """Creates the curves of an implicit function.
+
+        Parameters
+        ----------
+        func
+            The function to graph, in the form of f(x, y) = 0.
+        min_depth
+            The minimum depth of the function to calculate.
+        max_quads
+            The maximum number of quads to use.
+        kwargs
+            Additional parameters to pass into :class:`ImplicitFunction`
+
+        Examples
+        --------
+        .. manim:: ImplicitExample
+            :save_last_frame:
+
+            class ImplicitExample(Scene):
+                def construct(self):
+                    ax = Axes()
+                    a = ax.get_implicit_curve(
+                        lambda x, y: y * (x - y) ** 2 - 4 * x - 8, color=BLUE
+                    )
+                    self.add(ax, a)
+        """
+        graph = ImplicitFunction(
+            func=func,
+            x_range=self.x_range[:2],
+            y_range=self.y_range[:2],
+            min_depth=min_depth,
+            max_quads=max_quads,
+            **kwargs,
+        )
+        (
+            graph.stretch(self.get_x_unit_size(), 0, about_point=ORIGIN)
+            .stretch(self.get_y_unit_size(), 1, about_point=ORIGIN)
+            .shift(self.get_origin())
+        )
+        return graph
+
     def get_parametric_curve(self, function, **kwargs):
         dim = self.dimension
         graph = ParametricFunction(
@@ -702,7 +754,11 @@ class CoordinateSystem:
         graph.underlying_function = function
         return graph
 
-    def input_to_graph_point(self, x: float, graph: "ParametricFunction") -> np.ndarray:
+    def input_to_graph_point(
+        self,
+        x: float,
+        graph: Union["ParametricFunction", VMobject],
+    ) -> np.ndarray:
         """Returns the coordinates of the point on a ``graph`` corresponding to an ``x`` value.
 
         Examples
@@ -733,6 +789,11 @@ class CoordinateSystem:
         -------
         :class:`np.ndarray`
             The coordinates of the point on the :attr:`graph` corresponding to the :attr:`x` value.
+
+        Raises
+        ------
+        :exc:`ValueError`
+            When the target x is not in the range of the line graph.
         """
 
         if hasattr(graph, "underlying_function"):
@@ -743,13 +804,15 @@ class CoordinateSystem:
                     0
                 ],
                 target=x,
-                lower_bound=self.x_range[0],
-                upper_bound=self.x_range[1],
+                lower_bound=0,
+                upper_bound=1,
             )
             if alpha is not None:
                 return graph.point_from_proportion(alpha)
             else:
-                return None
+                raise ValueError(
+                    f"x={x} not located in the range of the graph ([{self.p2c(graph.get_start())[0]}, {self.p2c(graph.get_end())[0]}])",
+                )
 
     def i2gp(self, x: float, graph: "ParametricFunction") -> np.ndarray:
         """
@@ -992,7 +1055,7 @@ class CoordinateSystem:
                             self.coords_to_point(x + width_scale_factor * dx, y_point),
                             graph_point,
                         ],
-                    )
+                    ),
                 )
             )
 
@@ -1019,15 +1082,13 @@ class CoordinateSystem:
     def get_area(
         self,
         graph: "ParametricFunction",
-        x_range: Optional[Sequence[float]] = None,
+        x_range: Optional[Tuple[float, float]] = None,
         color: Union[Color, Iterable[Color]] = [BLUE, GREEN],
         opacity: float = 0.3,
-        dx_scaling: float = 1,
-        bounded: "ParametricFunction" = None,
+        bounded_graph: "ParametricFunction" = None,
         **kwargs,
     ):
-        """Returns a :class:`~.VGroup` of Riemann rectangles sufficiently small enough to visually
-        approximate the area under the graph passed.
+        """Returns a :class:`~.Polygon` representing the area under the graph passed.
 
         Examples
         --------
@@ -1042,7 +1103,6 @@ class CoordinateSystem:
                     area = ax.get_area(
                         curve,
                         x_range=(PI / 2, 3 * PI / 2),
-                        dx_scaling=10,
                         color=(GREEN_B, GREEN_D),
                         opacity=1,
                     )
@@ -1052,40 +1112,62 @@ class CoordinateSystem:
         Parameters
         ----------
         graph
-            The graph/curve for which the area needs to be determined.
+            The graph/curve for which the area needs to be gotten.
         x_range
             The range of the minimum and maximum x-values of the area. ``x_range = [x_min, x_max]``.
         color
-            The color of the area. Creates a gradient if an iterable of colors is provided.
+            The color of the area. Creates a gradient if a list of colors is provided.
         opacity
             The opacity of the area.
-        bounded
+        bounded_graph
             If a secondary :attr:`graph` is specified, encloses the area between the two curves.
-        dx_scaling
-            The factor by which the :attr:`dx` value is scaled.
         kwargs
-            Additional arguments to be passed to :meth:`~.CoordinateSystem.get_area`.
+            Additional parameters passed to :class:`~.Polygon`
 
         Returns
         -------
-        :class:`~.VGroup`
-            The :class:`~.VGroup` containing the Riemann Rectangles.
-        """
+        :class:`~.Polygon`
+            The :class:`~.Polygon` representing the area.
 
-        dx = kwargs.pop("dx", None) or self.x_range[2] / 500
-        return self.get_riemann_rectangles(
-            graph,
-            x_range=x_range,
-            dx=dx * dx_scaling,
-            bounded_graph=bounded,
-            blend=True,
-            color=color,
-            show_signed_area=kwargs.pop("show_signed_area", None) or False,
-            **kwargs,
-        ).set_opacity(opacity=opacity)
+        Raises
+        ------
+        :exc:`ValueError`
+            When x_ranges do not match (either area x_range, graph's x_range or bounded_graph's x_range).
+        """
+        if x_range is None:
+            a = graph.t_min
+            b = graph.t_max
+        else:
+            a, b = x_range
+        if bounded_graph is not None:
+            if bounded_graph.t_min > b:
+                raise ValueError(
+                    f"Ranges not matching: {bounded_graph.t_min} < {b}",
+                )
+            if bounded_graph.t_max < a:
+                raise ValueError(
+                    f"Ranges not matching: {bounded_graph.t_max} > {a}",
+                )
+            a = max(a, bounded_graph.t_min)
+            b = min(b, bounded_graph.t_max)
+
+        if bounded_graph is None:
+            points = (
+                [self.c2p(a)]
+                + [p for p in graph.points if a <= self.p2c(p)[0] <= b]
+                + [self.c2p(b)]
+            )
+        else:
+            points = [p for p in graph.points if a <= self.p2c(p)[0] <= b] + [
+                p for p in bounded_graph.points if a <= self.p2c(p)[0] <= b
+            ][::-1]
+        return Polygon(*points, **kwargs).set_opacity(opacity).set_color(color)
 
     def angle_of_tangent(
-        self, x: float, graph: "ParametricFunction", dx: float = 1e-8
+        self,
+        x: float,
+        graph: "ParametricFunction",
+        dx: float = 1e-8,
     ) -> float:
         """Returns the angle to the x-axis of the tangent
         to the plotted curve at a particular x-value.
@@ -1311,20 +1393,24 @@ class CoordinateSystem:
 
         if dx_label is not None:
             group.dx_label.next_to(
-                group.dx_line, np.sign(dx) * DOWN, buff=group.dx_label.height / 2
+                group.dx_line,
+                np.sign(dx) * DOWN,
+                buff=group.dx_label.height / 2,
             )
             group.dx_label.set_color(group.dx_line.get_color())
 
         if dy_label is not None:
             group.df_label.next_to(
-                group.df_line, np.sign(dx) * RIGHT, buff=group.df_label.height / 2
+                group.df_line,
+                np.sign(dx) * RIGHT,
+                buff=group.df_label.height / 2,
             )
             group.df_label.set_color(group.df_line.get_color())
 
         if include_secant_line:
             group.secant_line = Line(p1, p2, color=secant_line_color)
-            group.secant_line.scale_in_place(
-                secant_line_length / group.secant_line.get_length()
+            group.secant_line.scale(
+                secant_line_length / group.secant_line.get_length(),
             )
             group.add(group.secant_line)
         return group
@@ -1443,7 +1529,8 @@ class CoordinateSystem:
 
         T_label_group = VGroup()
         triangle = RegularPolygon(n=3, start_angle=np.pi / 2, stroke_width=0).set_fill(
-            color=triangle_color, opacity=1
+            color=triangle_color,
+            opacity=1,
         )
         triangle.height = triangle_size
         triangle.move_to(self.coords_to_point(x_val, 0), UP)
@@ -1453,7 +1540,9 @@ class CoordinateSystem:
             T_label_group.add(t_label)
 
         v_line = self.get_vertical_line(
-            self.i2gp(x_val, graph), color=line_color, line_func=line_func
+            self.i2gp(x_val, graph),
+            color=line_color,
+            line_func=line_func,
         )
 
         T_label_group.add(triangle, v_line)
@@ -1515,10 +1604,12 @@ class Axes(VGroup, CoordinateSystem, metaclass=ConvertToOpenGL):
         )
 
         self.x_axis_config = merge_dicts_recursively(
-            self.axis_config, self.x_axis_config
+            self.axis_config,
+            self.x_axis_config,
         )
         self.y_axis_config = merge_dicts_recursively(
-            self.axis_config, self.y_axis_config
+            self.axis_config,
+            self.y_axis_config,
         )
 
         self.x_axis = self._create_axis(self.x_range, self.x_axis_config, self.x_length)
@@ -1817,8 +1908,7 @@ class ThreeDAxes(Axes):
         **kwargs,
     ):
 
-        Axes.__init__(
-            self,
+        super().__init__(
             x_range=x_range,
             x_length=x_length,
             y_range=y_range,
@@ -1832,7 +1922,8 @@ class ThreeDAxes(Axes):
         self.z_axis_config = {}
         self._update_default_configs((self.z_axis_config,), (z_axis_config,))
         self.z_axis_config = merge_dicts_recursively(
-            self.axis_config, self.z_axis_config
+            self.axis_config,
+            self.z_axis_config,
         )
 
         self.z_normal = z_normal
@@ -1852,7 +1943,7 @@ class ThreeDAxes(Axes):
         self.add(z_axis)
         self.z_axis = z_axis
 
-        if not config.renderer == "opengl":
+        if config.renderer != "opengl":
             self._add_3d_pieces()
             self._set_axis_shading()
 
@@ -2083,14 +2174,14 @@ class NumberPlane(Axes):
         x_lines1, x_lines2 = self._get_lines_parallel_to_axis(
             x_axis,
             y_axis,
-            self.x_axis.x_step,
+            self.y_axis.x_step,
             self.faded_line_ratio,
         )
 
         y_lines1, y_lines2 = self._get_lines_parallel_to_axis(
             y_axis,
             x_axis,
-            self.y_axis.x_step,
+            self.x_axis.x_step,
             self.faded_line_ratio,
         )
 
@@ -2299,7 +2390,7 @@ class PolarPlane(Axes):
             self.azimuth_units = azimuth_units
         else:
             raise ValueError(
-                "Invalid azimuth units. Expected one of: PI radians, TAU radians, degrees, gradians or None."
+                "Invalid azimuth units. Expected one of: PI radians, TAU radians, degrees, gradians or None.",
             )
 
         if azimuth_direction in ["CW", "CCW"]:
@@ -2552,7 +2643,7 @@ class PolarPlane(Axes):
                         self.get_right()[0]
                         * np.sin(d * (i * TAU) + self.azimuth_offset),
                         0,
-                    ]
+                    ],
                 ),
             }
             for i in a_values
@@ -2560,7 +2651,8 @@ class PolarPlane(Axes):
         if self.azimuth_units == "PI radians" or self.azimuth_units == "TAU radians":
             a_tex = [
                 self.get_radian_label(
-                    i["label"], font_size=self.azimuth_label_font_size
+                    i["label"],
+                    font_size=self.azimuth_label_font_size,
                 ).next_to(
                     i["point"],
                     direction=i["point"],
@@ -2598,7 +2690,8 @@ class PolarPlane(Axes):
         elif self.azimuth_units is None:
             a_tex = [
                 MathTex(
-                    f'{i["label"]:g}', font_size=self.azimuth_label_font_size
+                    f'{i["label"]:g}',
+                    font_size=self.azimuth_label_font_size,
                 ).next_to(
                     i["point"],
                     direction=i["point"],
