@@ -180,7 +180,6 @@ from ...mobject.types.opengl_vectorized_mobject import (
     OpenGLVGroup,
 )
 from ...utils.color import BLACK
-from ...utils.deprecation import deprecated
 from ...utils.strings import split_string_list_to_isolate_substrings
 from ...utils.tex_file_writing import tex_to_svg_file
 from .style_utils import parse_style
@@ -234,8 +233,7 @@ class OpenGLSingleStringMathTex(OpenGLSVGMobject):
             environment=self.tex_environment,
             tex_template=self.tex_template,
         )
-        OpenGLSVGMobject.__init__(
-            self,
+        super().__init__(
             file_name=file_name,
             should_center=should_center,
             stroke_width=stroke_width,
@@ -399,8 +397,7 @@ class OpenGLMathTex(OpenGLSingleStringMathTex):
         self.tex_environment = tex_environment
         tex_strings = self.break_up_tex_strings(tex_strings)
         self.tex_strings = tex_strings
-        OpenGLSingleStringMathTex.__init__(
-            self,
+        super().__init__(
             self.arg_separator.join(tex_strings),
             tex_environment=self.tex_environment,
             tex_template=self.tex_template,
@@ -414,7 +411,8 @@ class OpenGLMathTex(OpenGLSingleStringMathTex):
 
     def break_up_tex_strings(self, tex_strings):
         substrings_to_isolate = op.add(
-            self.substrings_to_isolate, list(self.tex_to_color_map.keys())
+            self.substrings_to_isolate,
+            list(self.tex_to_color_map.keys()),
         )
         split_list = split_string_list_to_isolate_substrings(
             tex_strings, *substrings_to_isolate
@@ -524,8 +522,7 @@ class OpenGLTex(OpenGLMathTex):
     def __init__(
         self, *tex_strings, arg_separator="", tex_environment="center", **kwargs
     ):
-        OpenGLMathTex.__init__(
-            self,
+        super().__init__(
             *tex_strings,
             arg_separator=arg_separator,
             tex_environment=tex_environment,
