@@ -36,7 +36,6 @@ from ...mobject.svg.svg_path import SVGPathMobject
 from ...mobject.types.vectorized_mobject import VectorizedPoint, VGroup
 from ...utils.color import BLACK, WHITE
 from ...utils.deprecation import deprecated_params
-from ...utils.tex import TexTemplate
 from ...utils.tex_file_writing import tex_to_svg_file
 from .style_utils import parse_style
 
@@ -299,8 +298,8 @@ class MathTex(SingleStringMathTex):
                         compilation error. If you didn't use the double brace
                         split intentionally, add spaces between the braces to
                         avoid the automatic splitting: {{ ... }} --> { { ... } }.
-                        """
-                    )
+                        """,
+                    ),
                 )
             raise compilation_error
         self.set_color_by_tex_to_color_map(self.tex_to_color_map)
@@ -323,9 +322,10 @@ class MathTex(SingleStringMathTex):
             [
                 f"({re.escape(ss)})"
                 for ss in it.chain(
-                    self.substrings_to_isolate, self.tex_to_color_map.keys()
+                    self.substrings_to_isolate,
+                    self.tex_to_color_map.keys(),
                 )
-            ]
+            ],
         )
         pattern = "|".join(patterns)
         if pattern:
