@@ -73,6 +73,7 @@ from ..animation.creation import *
 from ..constants import *
 from ..mobject.geometry import Line, Polygon
 from ..mobject.numbers import DecimalNumber, Integer
+from ..mobject.shape_matchers import BackgroundRectangle
 from ..mobject.svg.tex_mobject import MathTex
 from ..mobject.svg.text_mobject import Paragraph
 from ..mobject.types.vectorized_mobject import VGroup, VMobject
@@ -157,7 +158,8 @@ class Table(VGroup):
         include_background_rectangle: bool = False,
         background_rectangle_color: Color = BLACK,
         element_to_mobject: Callable[
-            [Union[float, str, "VMobject"]], "VMobject"
+            [Union[float, str, "VMobject"]],
+            "VMobject",
         ] = Paragraph,
         element_to_mobject_config: dict = {},
         arrange_in_grid_config: dict = {},
@@ -247,7 +249,8 @@ class Table(VGroup):
             self.add_background_rectangle(color=self.background_rectangle_color)
 
     def _table_to_mob_table(
-        self, table: Iterable[Iterable[Union[float, str, "VMobject"]]]
+        self,
+        table: Iterable[Iterable[Union[float, str, "VMobject"]]],
     ) -> List:
         """Initilaizes the entries of ``table`` as :class:`~.VMobject`.
 
@@ -562,7 +565,8 @@ class Table(VGroup):
         return self
 
     def get_entries(
-        self, pos: Optional[Sequence[int]] = None
+        self,
+        pos: Optional[Sequence[int]] = None,
     ) -> Union[VMobject, VGroup]:
         """Return the individual entries of the table (including labels) or one specific entry
         if the parameter, ``pos``,  is set.
@@ -613,7 +617,8 @@ class Table(VGroup):
             return self.elements
 
     def get_entries_without_labels(
-        self, pos: Optional[Sequence[int]] = None
+        self,
+        pos: Optional[Sequence[int]] = None,
     ) -> Union[VMobject, VGroup]:
         """Return the individual entries of the table (without labels) or one specific entry
         if the parameter, ``pos``, is set.
@@ -812,6 +817,42 @@ class Table(VGroup):
         rec = Polygon(edge_UL, edge_UR, edge_DR, edge_DL, **kwargs)
         return rec
 
+    def get_highlighted_cell(
+        self, pos: Sequence[int] = (1, 1), color: Color = YELLOW, **kwargs
+    ) -> "BackgroundRectangle":
+        """Returns a :class:`~.BackgroundRectangle` of the cell at the given position.
+
+        Parameters
+        ----------
+        pos
+            The position of a specific entry on the table. ``(1,1)`` being the top left entry
+            of the table.
+        color
+            The color used to highlight the cell.
+        kwargs : Any
+            Additional arguments to be passed to :class:`~.BackgroundRectangle`.
+
+        Examples
+        --------
+
+        .. manim:: GetHighlightedCellExample
+            :save_last_frame:
+
+            class GetHighlightedCellExample(Scene):
+                def construct(self):
+                    table = Table(
+                        [["First", "Second"],
+                        ["Third","Fourth"]],
+                        row_labels=[Text("R1"), Text("R2")],
+                        col_labels=[Text("C1"), Text("C2")])
+                    highlight = table.get_highlighted_cell((2,2), color=GREEN)
+                    table.add_to_back(highlight)
+                    self.add(table)
+        """
+        cell = self.get_cell(pos)
+        bg_cell = BackgroundRectangle(cell, color=color, **kwargs)
+        return bg_cell
+
     def add_highlighted_cell(
         self, pos: Sequence[int] = (1, 1), color: Color = YELLOW, **kwargs
     ) -> "Table":
@@ -825,7 +866,7 @@ class Table(VGroup):
         color
             The color used to highlight the cell.
         kwargs : Any
-            Additional arguments to be passed to :meth:`~.add_background_rectangle`.
+            Additional arguments to be passed to :class:`~.BackgroundRectangle`.
 
         Examples
         --------
@@ -843,11 +884,10 @@ class Table(VGroup):
                     table.add_highlighted_cell((2,2), color=GREEN)
                     self.add(table)
         """
-        cell = self.get_cell(pos)
+        bg_cell = self.get_highlighted_cell(pos, color=color)
+        self.add_to_back(bg_cell)
         entry = self.get_entries(pos)
-        entry.add_background_rectangle(color=color, **kwargs)
-        entry.background_rectangle.stretch_to_fit_height(cell.get_height())
-        entry.background_rectangle.stretch_to_fit_width(cell.get_width())
+        entry.background_rectangle = bg_cell
         return self
 
     def create(
