@@ -30,9 +30,11 @@ from ...utils.bezier import (
     integer_interpolate,
     interpolate,
     partial_bezier_points,
+    point_lies_on_bezier,
+    proportions_along_bezier_curve_for_point,
 )
 from ...utils.color import BLACK, WHITE, color_to_rgba
-from ...utils.deprecation import deprecated_params
+from ...utils.deprecation import deprecated, deprecated_params
 from ...utils.iterables import make_even, stretch_array_to_length, tuplify
 from ...utils.simple_functions import clip_in_place
 from ...utils.space_ops import rotate_vector, shoelace_direction
@@ -103,7 +105,7 @@ class VMobject(Mobject):
         self.shade_in_3d = shade_in_3d
         self.tolerance_for_point_equality = tolerance_for_point_equality
         self.n_points_per_cubic_curve = n_points_per_cubic_curve
-        Mobject.__init__(self, **kwargs)
+        super().__init__(**kwargs)
 
     def get_group_class(self):
         return VGroup
@@ -150,7 +152,7 @@ class VMobject(Mobject):
         colors = list(tuplify(color))
         opacities = list(tuplify(opacity))
         rgbas = np.array(
-            [color_to_rgba(c, o) for c, o in zip(*make_even(colors, opacities))]
+            [color_to_rgba(c, o) for c, o in zip(*make_even(colors, opacities))],
         )
 
         sheen_factor = self.get_sheen_factor()
@@ -236,7 +238,12 @@ class VMobject(Mobject):
         return self
 
     def set_stroke(
-        self, color=None, width=None, opacity=None, background=False, family=True
+        self,
+        color=None,
+        width=None,
+        opacity=None,
+        background=False,
+        family=True,
     ):
         if family:
             for submobject in self.submobjects:
@@ -295,7 +302,9 @@ class VMobject(Mobject):
         )
         if sheen_factor:
             self.set_sheen(
-                factor=sheen_factor, direction=sheen_direction, family=family
+                factor=sheen_factor,
+                direction=sheen_direction,
+                family=family,
             )
         if background_image:
             self.color_using_background_image(background_image)
@@ -361,7 +370,8 @@ class VMobject(Mobject):
         self.set_fill(opacity=factor * self.get_fill_opacity(), family=False)
         self.set_stroke(opacity=factor * self.get_stroke_opacity(), family=False)
         self.set_background_stroke(
-            opacity=factor * self.get_stroke_opacity(background=True), family=False
+            opacity=factor * self.get_stroke_opacity(background=True),
+            family=False,
         )
         super().fade(darkness, family)
         return self
@@ -481,7 +491,9 @@ class VMobject(Mobject):
         if family:
             for submob in self.get_family():
                 submob.sheen_direction = rotate_vector(
-                    submob.sheen_direction, angle, axis
+                    submob.sheen_direction,
+                    angle,
+                    axis,
                 )
         else:
             self.sheen_direction = rotate_vector(self.sheen_direction, angle, axis)
@@ -537,7 +549,7 @@ class VMobject(Mobject):
             direction = self.get_sheen_direction()
             c = self.get_center()
             bases = np.array(
-                [self.get_edge_center(vect) - c for vect in [RIGHT, UP, OUT]]
+                [self.get_edge_center(vect) - c for vect in [RIGHT, UP, OUT]],
             ).transpose()
             offset = np.dot(bases, direction)
             return (c - offset, c + offset)
@@ -563,11 +575,11 @@ class VMobject(Mobject):
                 submob.z_index_group = self
         return self
 
-    # Points
     def set_points(self, points):
         self.points = np.array(points)
         return self
 
+    @deprecated(since="0.11.0", replacement="self.points")
     def get_points(self):
         return np.array(self.points)
 
@@ -621,13 +633,20 @@ class VMobject(Mobject):
         return self
 
     def add_cubic_bezier_curve(
-        self, anchor1: np.ndarray, handle1: np.ndarray, handle2: np.ndarray, anchor2
+        self,
+        anchor1: np.ndarray,
+        handle1: np.ndarray,
+        handle2: np.ndarray,
+        anchor2,
     ) -> None:
         # TODO, check the len(self.points) % 4 == 0?
         self.append_points([anchor1, handle1, handle2, anchor2])
 
     def add_cubic_bezier_curve_to(
-        self, handle1: np.ndarray, handle2: np.ndarray, anchor: np.ndarray
+        self,
+        handle1: np.ndarray,
+        handle2: np.ndarray,
+        anchor: np.ndarray,
     ) -> None:
         """Add cubic bezier curve to the path.
 
@@ -650,7 +669,9 @@ class VMobject(Mobject):
             self.append_points([self.get_last_point()] + new_points)
 
     def add_quadratic_bezier_curve_to(
-        self, handle: np.ndarray, anchor: np.ndarray
+        self,
+        handle: np.ndarray,
+        anchor: np.ndarray,
     ) -> "VMobject":
         """Add Quadratic bezier curve to the path."""
         # How does one approximate a quadratic with a cubic?
@@ -831,7 +852,7 @@ class VMobject(Mobject):
     def apply_function(self, function):
         factor = self.pre_function_handle_to_anchor_scale_factor
         self.scale_handle_to_anchor_distances(factor)
-        Mobject.apply_function(self, function)
+        super().apply_function(function)
         self.scale_handle_to_anchor_distances(1.0 / factor)
         if self.make_smooth_after_applying_functions:
             self.make_smooth()
@@ -937,10 +958,12 @@ class VMobject(Mobject):
         return (points[i : i + nppcc] for i in range(0, len(points), nppcc))
 
     def get_cubic_bezier_tuples(self):
-        return self.get_cubic_bezier_tuples_from_points(self.get_points())
+        return self.get_cubic_bezier_tuples_from_points(self.points)
 
     def _gen_subpaths_from_points(
-        self, points: np.ndarray, filter_func: typing.Callable[[int], bool]
+        self,
+        points: np.ndarray,
+        filter_func: typing.Callable[[int], bool],
     ) -> typing.Tuple:
         """Given an array of points defining the bezier curves of the vmobject, return subpaths formed by these points.
         Here, Two bezier curves form a path if at least two of their anchors are evaluated True by the relation defined by filter_func.
@@ -976,7 +999,7 @@ class VMobject(Mobject):
             self._gen_subpaths_from_points(
                 points,
                 lambda n: not self.consider_points_equals(points[n - 1], points[n]),
-            )
+            ),
         )
 
     def gen_subpaths_from_points_2d(self, points):
@@ -995,7 +1018,7 @@ class VMobject(Mobject):
         typing.Tuple
             subpaths.
         """
-        return self.get_subpaths_from_points(self.get_points())
+        return self.get_subpaths_from_points(self.points)
 
     def get_nth_curve_points(self, n: int) -> np.ndarray:
         """Returns the points defining the nth curve of the vmobject.
@@ -1029,8 +1052,34 @@ class VMobject(Mobject):
         """
         return bezier(self.get_nth_curve_points(n))
 
+    def get_nth_curve_length(
+        self,
+        n: int,
+        sample_points: Optional[int] = None,
+    ) -> float:
+        """Returns the (approximate) length of the nth curve.
+
+        Parameters
+        ----------
+        n
+            The index of the desired curve.
+        sample_points
+            The number of points to sample to find the length.
+
+        Returns
+        -------
+        length : :class:`float`
+            The length of the nth curve.
+        """
+
+        _, length = self.get_nth_curve_function_with_length(n, sample_points)
+
+        return length
+
     def get_nth_curve_function_with_length(
-        self, n: int, sample_points: Optional[int] = None
+        self,
+        n: int,
+        sample_points: Optional[int] = None,
     ) -> typing.Tuple[typing.Callable[[float], np.ndarray], float]:
         """Returns the expression of the nth curve along with its (approximate) length.
 
@@ -1136,11 +1185,11 @@ class VMobject(Mobject):
 
         self.throw_error_if_no_points()
         if alpha == 1:
-            return self.get_points()[-1]
+            return self.points[-1]
 
         curves_and_lengths = tuple(self.get_curve_functions_with_lengths())
 
-        target_length = alpha * np.sum(length for _, length in curves_and_lengths)
+        target_length = alpha * sum(length for _, length in curves_and_lengths)
         current_length = 0
 
         for curve, length in curves_and_lengths:
@@ -1154,6 +1203,62 @@ class VMobject(Mobject):
 
             current_length += length
 
+    def proportion_from_point(
+        self,
+        point: typing.Iterable[typing.Union[float, int]],
+    ) -> float:
+        """Returns the proportion along the path of the :class:`VMobject`
+        a particular given point is at.
+
+        Parameters
+        ----------
+        point
+            The Cartesian coordinates of the point which may or may not lie on the :class:`VMobject`
+
+        Returns
+        -------
+        float
+            The proportion along the path of the :class:`VMobject`.
+
+        Raises
+        ------
+        :exc:`ValueError`
+            If ``point`` does not lie on the curve.
+        :exc:`Exception`
+            If the :class:`VMobject` has no points.
+        """
+        self.throw_error_if_no_points()
+
+        # Iterate over each bezier curve that the ``VMobject`` is composed of, checking
+        # if the point lies on that curve. If it does not lie on that curve, add
+        # the whole length of the curve to ``target_length`` and move onto the next
+        # curve. If the point does lie on the curve, add how far along the curve
+        # the point is to ``target_length``.
+        # Then, divide ``target_length`` by the total arc length of the shape to get
+        # the proportion along the ``VMobject`` the point is at.
+
+        num_curves = self.get_num_curves()
+        total_length = self.get_arc_length()
+        target_length = 0
+        for n in range(num_curves):
+            control_points = self.get_nth_curve_points(n)
+            length = self.get_nth_curve_length(n)
+            proportions_along_bezier = proportions_along_bezier_curve_for_point(
+                point,
+                control_points,
+            )
+            if len(proportions_along_bezier) > 0:
+                proportion_along_nth_curve = max(proportions_along_bezier)
+                target_length += length * proportion_along_nth_curve
+                break
+            target_length += length
+        else:
+            raise ValueError(f"Point {point} does not lie on this curve.")
+
+        alpha = target_length / total_length
+
+        return alpha
+
     def get_anchors_and_handles(self) -> typing.Iterable[np.ndarray]:
         """Returns anchors1, handles1, handles2, anchors2,
         where (anchors1[i], handles1[i], handles2[i], anchors2[i])
@@ -1200,7 +1305,7 @@ class VMobject(Mobject):
         if self.points.shape[0] == 1:
             return self.points
         return np.array(
-            list(it.chain(*zip(self.get_start_anchors(), self.get_end_anchors())))
+            list(it.chain(*zip(self.get_start_anchors(), self.get_end_anchors()))),
         )
 
     def get_points_defining_boundary(self):
@@ -1221,10 +1326,10 @@ class VMobject(Mobject):
             The length of the :class:`VMobject`.
         """
 
-        return np.sum(
+        return sum(
             length
             for _, length in self.get_curve_functions_with_lengths(
-                sample_points=sample_points_per_curve
+                sample_points=sample_points_per_curve,
             )
         )
 
@@ -1292,7 +1397,7 @@ class VMobject(Mobject):
         if self.has_new_path_started():
             new_path_point = self.get_last_point()
 
-        new_points = self.insert_n_curves_to_point_list(n, self.get_points())
+        new_points = self.insert_n_curves_to_point_list(n, self.points)
         self.set_points(new_points)
 
         if new_path_point is not None:
@@ -1341,7 +1446,9 @@ class VMobject(Mobject):
             alphas = np.linspace(0, 1, sf + 1)
             for a1, a2 in zip(alphas, alphas[1:]):
                 new_points = np.append(
-                    new_points, partial_bezier_points(quad, a1, a2), axis=0
+                    new_points,
+                    partial_bezier_points(quad, a1, a2),
+                    axis=0,
                 )
         return new_points
 
@@ -1385,7 +1492,10 @@ class VMobject(Mobject):
                 setattr(self, attr, getattr(mobject2, attr))
 
     def pointwise_become_partial(
-        self, vmobject: "VMobject", a: float, b: float
+        self,
+        vmobject: "VMobject",
+        a: float,
+        b: float,
     ) -> "VMobject":
         """Given two bounds a and b, transforms the points of the self vmobject into the points of the vmobject
         passed as parameter with respect to the bounds. Points here stand for control points of the bezier curves (anchors and handles)
@@ -1422,17 +1532,19 @@ class VMobject(Mobject):
         if lower_index == upper_index:
             self.append_points(
                 partial_bezier_points(
-                    bezier_quads[lower_index], lower_residue, upper_residue
-                )
+                    bezier_quads[lower_index],
+                    lower_residue,
+                    upper_residue,
+                ),
             )
         else:
             self.append_points(
-                partial_bezier_points(bezier_quads[lower_index], lower_residue, 1)
+                partial_bezier_points(bezier_quads[lower_index], lower_residue, 1),
             )
             for quad in bezier_quads[lower_index + 1 : upper_index]:
                 self.append_points(quad)
             self.append_points(
-                partial_bezier_points(bezier_quads[upper_index], 0, upper_residue)
+                partial_bezier_points(bezier_quads[upper_index], 0, upper_residue),
             )
         return self
 
@@ -2064,7 +2176,7 @@ class CurvesAsSubmobjects(VGroup):
     """
 
     def __init__(self, vmobject, **kwargs):
-        VGroup.__init__(self, **kwargs)
+        super().__init__(**kwargs)
         tuples = vmobject.get_cubic_bezier_tuples()
         for tup in tuples:
             part = VMobject()
@@ -2135,7 +2247,8 @@ class DashedVMobject(VMobject, metaclass=ConvertToOpenGL):
             self.add(
                 *(
                     vmobject.get_subcurve(
-                        i * (dash_len + void_len), i * (dash_len + void_len) + dash_len
+                        i * (dash_len + void_len),
+                        i * (dash_len + void_len) + dash_len,
                     )
                     for i in range(n)
                 )
