@@ -9,7 +9,7 @@ __all__ = [
 import itertools as it
 import random
 from math import ceil, floor
-from typing import Callable, Optional, Sequence, Tuple, Type
+from typing import Callable, Iterable, Optional, Sequence, Tuple, Type
 
 import numpy as np
 from colour import Color
@@ -20,20 +20,19 @@ from ..animation.composition import AnimationGroup, Succession
 from ..animation.creation import Create
 from ..animation.indication import ShowPassingFlash
 from ..animation.update import UpdateFromAlphaFunc
-from ..constants import RIGHT, UP
+from ..constants import OUT, RIGHT, UP
 from ..mobject.geometry import Vector
 from ..mobject.mobject import Mobject
 from ..mobject.types.vectorized_mobject import VGroup, VMobject
 from ..utils.bezier import interpolate, inverse_interpolate
 from ..utils.color import BLUE_E, GREEN, RED, YELLOW, color_to_rgb, rgb_to_color
+from ..utils.deprecation import deprecated_params
 from ..utils.rate_functions import ease_out_sine, linear
 from ..utils.simple_functions import sigmoid
+from .types.opengl_vectorized_mobject import OpenGLVMobject
 
 DEFAULT_SCALAR_FIELD_COLORS: list = [BLUE_E, GREEN, YELLOW, RED]
 
-# def get_norm(p):
-#     return np.linalg.norm(p)
-
 
 class VectorField(VGroup):
     """A vector field.
@@ -91,7 +90,9 @@ class VectorField(VGroup):
                     max_color_scheme_value,
                 )
                 alpha = inverse_interpolate(
-                    min_color_scheme_value, max_color_scheme_value, color_value
+                    min_color_scheme_value,
+                    max_color_scheme_value,
+                    color_value,
                 )
                 alpha *= len(self.rgbs) - 1
                 c1 = self.rgbs[int(alpha)]
@@ -108,7 +109,8 @@ class VectorField(VGroup):
 
     @staticmethod
     def shift_func(
-        func: Callable[[np.ndarray], np.ndarray], shift_vector: np.ndarray
+        func: Callable[[np.ndarray], np.ndarray],
+        shift_vector: np.ndarray,
     ) -> Callable[[np.ndarray], np.ndarray]:
         """Shift a vector field function.
 
@@ -129,7 +131,8 @@ class VectorField(VGroup):
 
     @staticmethod
     def scale_func(
-        func: Callable[[np.ndarray], np.ndarray], scalar: float
+        func: Callable[[np.ndarray], np.ndarray],
+        scalar: float,
     ) -> Callable[[np.ndarray], np.ndarray]:
         """Scale a vector field function.
 
@@ -146,7 +149,7 @@ class VectorField(VGroup):
 
             class ScaleVectorFieldFunction(Scene):
                 def construct(self):
-                    func = lambda pos: np.sin(pos[1])*RIGHT+np.cos(pos[0])*UP
+                    func = lambda pos: np.sin(pos[1]) * RIGHT + np.cos(pos[0]) * UP
                     vector_field = ArrowVectorField(func)
                     self.add(vector_field)
                     self.wait()
@@ -164,7 +167,11 @@ class VectorField(VGroup):
         return lambda p: func(p * scalar)
 
     def nudge(
-        self, mob: Mobject, dt: float = 1, substeps: int = 1, pointwise: bool = False
+        self,
+        mob: Mobject,
+        dt: float = 1,
+        substeps: int = 1,
+        pointwise: bool = False,
     ) -> "VectorField":
         """Nudge a :class:`~.Mobject` along the vector field.
 
@@ -179,9 +186,9 @@ class VectorField(VGroup):
             The amount of steps the whole nudge is divided into. Higher values
             give more accurate approximations.
         pointwise
-            Whether to move the mobject along the vector field. If `True` the
+            Whether to move the mobject along the vector field. If `False` the
             vector field takes effect on the center of the given
-            :class:`~.Mobject`. If `False` the vector field takes effect on the
+            :class:`~.Mobject`. If `True` the vector field takes effect on the
             points of the individual points of the :class:`~.Mobject`,
             potentially distorting it.
 
@@ -197,8 +204,10 @@ class VectorField(VGroup):
 
             class Nudging(Scene):
                 def construct(self):
-                    func = lambda pos: np.sin(pos[1]/2)*RIGHT+np.cos(pos[0]/2)*UP
-                    vector_field = ArrowVectorField(func, delta_x=1, delta_y=1, length_func=lambda x:x/2)
+                    func = lambda pos: np.sin(pos[1] / 2) * RIGHT + np.cos(pos[0] / 2) * UP
+                    vector_field = ArrowVectorField(
+                        func, x_range=[-7, 7, 1], y_range=[-4, 4, 1], length_func=lambda x: x / 2
+                    )
                     self.add(vector_field)
                     circle = Circle(radius=2).shift(LEFT)
                     self.add(circle.copy().set_color(GRAY))
@@ -235,7 +244,7 @@ class VectorField(VGroup):
             return step_size / 6.0 * (k_1 + 2.0 * k_2 + 2.0 * k_3 + k_4)
 
         step_size = dt / substeps
-        for i in range(substeps):
+        for _ in range(substeps):
             if pointwise:
                 mob.apply_function(lambda p: p + runge_kutta(self, p, step_size))
             else:
@@ -243,7 +252,10 @@ class VectorField(VGroup):
         return self
 
     def nudge_submobjects(
-        self, dt: float = 1, substeps: int = 1, pointwise: bool = False
+        self,
+        dt: float = 1,
+        substeps: int = 1,
+        pointwise: bool = False,
     ) -> "VectorField":
         """Apply a nudge along the vector field to all submobjects.
 
@@ -269,7 +281,9 @@ class VectorField(VGroup):
         return self
 
     def get_nudge_updater(
-        self, speed: float = 1, pointwise: bool = False
+        self,
+        speed: float = 1,
+        pointwise: bool = False,
     ) -> Callable[[Mobject, float], Mobject]:
         """Get an update function to move a :class:`~.Mobject` along the vector field.
 
@@ -290,7 +304,9 @@ class VectorField(VGroup):
         return lambda mob, dt: self.nudge(mob, dt * speed, pointwise=pointwise)
 
     def start_submobject_movement(
-        self, speed: float = 1, pointwise: bool = False
+        self,
+        speed: float = 1,
+        pointwise: bool = False,
     ) -> "VectorField":
         """Start continuously moving all submobjects along the vector field.
 
@@ -312,7 +328,8 @@ class VectorField(VGroup):
 
         self.stop_submobject_movement()
         self.submob_movement_updater = lambda mob, dt: mob.nudge_submobjects(
-            dt * speed, pointwise=pointwise
+            dt * speed,
+            pointwise=pointwise,
         )
         self.add_updater(self.submob_movement_updater)
         return self
@@ -351,7 +368,7 @@ class VectorField(VGroup):
         """
         if self.single_color:
             raise ValueError(
-                "There is no point in generating an image if the vector field uses a single color."
+                "There is no point in generating an image if the vector field uses a single color.",
             )
         ph = int(config["pixel_height"] / sampling_rate)
         pw = int(config["pixel_width"] / sampling_rate)
@@ -369,6 +386,47 @@ class VectorField(VGroup):
         rgbs = np.apply_along_axis(self.pos_to_rgb, 2, points_array)
         return Image.fromarray((rgbs * 255).astype("uint8"))
 
+    def get_vectorized_rgba_gradient_function(
+        self,
+        start: float,
+        end: float,
+        colors: Iterable,
+    ):
+        """
+        Generates a gradient of rgbas as a numpy array
+
+        Parameters
+        ----------
+        start
+            start value used for inverse interpolation at :func:`~.inverse_interpolate`
+        end
+            end value used for inverse interpolation at :func:`~.inverse_interpolate`
+        colors
+            list of colors to generate the gradient
+
+        Returns
+        -------
+            function to generate the gradients as numpy arrays representing rgba values
+        """
+        rgbs = np.array([color_to_rgb(c) for c in colors])
+
+        def func(values, opacity=1):
+            alphas = inverse_interpolate(start, end, np.array(values))
+            alphas = np.clip(alphas, 0, 1)
+            scaled_alphas = alphas * (len(rgbs) - 1)
+            indices = scaled_alphas.astype(int)
+            next_indices = np.clip(indices + 1, 0, len(rgbs) - 1)
+            inter_alphas = scaled_alphas % 1
+            inter_alphas = inter_alphas.repeat(3).reshape((len(indices), 3))
+            result = interpolate(rgbs[indices], rgbs[next_indices], inter_alphas)
+            result = np.concatenate(
+                (result, np.full([len(result), 1], opacity)),
+                axis=1,
+            )
+            return result
+
+        return func
+
 
 class ArrowVectorField(VectorField):
     """A :class:`VectorField` represented by a set of change vectors.
@@ -392,18 +450,15 @@ class ArrowVectorField(VectorField):
         The value of the color_scheme function to be mapped to the last color in `colors`. Higher values also result in the last color of the gradient.
     colors
         The colors defining the color gradient of the vector field.
-    x_min
-        The minimum x value for which to draw vectors.
-    x_max
-        The maximum x value for which to draw vectors.
-    y_min
-        The minimum y value for which to draw vectors.
-    y_max
-        The maximum y value for which to draw vectors.
-    delta_x
-        The distance in x direction between two vectors.
-    delta_y
-        The distance in y direction between two vectors.
+    x_range
+        A sequence of x_min, x_max, delta_x
+    y_range
+        A sequence of y_min, y_max, delta_y
+    z_range
+        A sequence of z_min, z_max, delta_z
+    three_dimensions
+        Enables three_dimensions. Default set to False, automatically turns True if
+        z_range is not None.
     length_func
         The function determining the displayed size of the vectors. The actual size
         of the vector is passed, the returned value will be used as display size for the
@@ -423,20 +478,20 @@ class ArrowVectorField(VectorField):
 
         class BasicUsage(Scene):
             def construct(self):
-                func = lambda pos: ((pos[0]*UR+pos[1]*LEFT)-pos)/3
+                func = lambda pos: ((pos[0] * UR + pos[1] * LEFT) - pos) / 3
                 self.add(ArrowVectorField(func))
 
     .. manim:: SizingAndSpacing
 
         class SizingAndSpacing(Scene):
             def construct(self):
-                func = lambda pos: np.sin(pos[0]/2)*UR+np.cos(pos[1]/2)*LEFT
-                vf = ArrowVectorField(func, delta_x=1)
+                func = lambda pos: np.sin(pos[0] / 2) * UR + np.cos(pos[1] / 2) * LEFT
+                vf = ArrowVectorField(func, x_range=[-7, 7, 1])
                 self.add(vf)
                 self.wait()
 
                 length_func = lambda x: x / 3
-                vf2 = ArrowVectorField(func, delta_x=1, length_func=length_func)
+                vf2 = ArrowVectorField(func, x_range=[-7, 7, 1], length_func=length_func)
                 self.play(vf.animate.become(vf2))
                 self.wait()
 
@@ -445,15 +500,23 @@ class ArrowVectorField(VectorField):
 
         class Coloring(Scene):
             def construct(self):
-                func = lambda pos: pos-LEFT*5
+                func = lambda pos: pos - LEFT * 5
                 colors = [RED, YELLOW, BLUE, DARK_GRAY]
-                min_radius = Circle(radius=2,  color=colors[0]).shift(LEFT*5)
-                max_radius = Circle(radius=10, color=colors[-1]).shift(LEFT*5)
-                vf = ArrowVectorField(func, min_color_scheme_value=2, max_color_scheme_value=10, colors=colors)
+                min_radius = Circle(radius=2, color=colors[0]).shift(LEFT * 5)
+                max_radius = Circle(radius=10, color=colors[-1]).shift(LEFT * 5)
+                vf = ArrowVectorField(
+                    func, min_color_scheme_value=2, max_color_scheme_value=10, colors=colors
+                )
                 self.add(vf, min_radius, max_radius)
 
     """
 
+    @deprecated_params(
+        params="x_min, x_max, delta_x, y_min, y_max, delta_y",
+        since="v0.10.0",
+        until="v0.11.0",
+        message="Please use x_range and y_range instead.",
+    )
     def __init__(
         self,
         func: Callable[[np.ndarray], np.ndarray],
@@ -463,18 +526,46 @@ class ArrowVectorField(VectorField):
         max_color_scheme_value: float = 2,
         colors: Sequence[Color] = DEFAULT_SCALAR_FIELD_COLORS,
         # Determining Vector positions:
-        x_min: float = -(config["frame_width"] + 1) / 2,
-        x_max: float = (config["frame_width"] + 1) / 2,
-        y_min: float = -(config["frame_height"] + 1) / 2,
-        y_max: float = (config["frame_height"] + 1) / 2,
-        delta_x: float = 0.5,
-        delta_y: float = 0.5,
+        x_range: Sequence[float] = None,
+        y_range: Sequence[float] = None,
+        z_range: Sequence[float] = None,
+        three_dimensions: bool = False,  # Automatically True if z_range is set
         # Takes in actual norm, spits out displayed norm
         length_func: Callable[[float], float] = lambda norm: 0.45 * sigmoid(norm),
         opacity: float = 1.0,
         vector_config: Optional[dict] = None,
         **kwargs
     ):
+        self.x_range = x_range or [
+            kwargs.pop("x_min", None) or floor(-config["frame_width"] / 2),
+            kwargs.pop("x_max", None) or ceil(config["frame_width"] / 2),
+        ]
+        self.y_range = y_range or [
+            kwargs.pop("y_min", None) or floor(-config["frame_height"] / 2),
+            kwargs.pop("y_max", None) or ceil(config["frame_height"] / 2),
+        ]
+        self.ranges = [self.x_range, self.y_range]
+
+        if three_dimensions or z_range:
+            self.z_range = z_range or self.y_range.copy()
+            self.ranges += [self.z_range]
+        else:
+            self.ranges += [[0, 0]]
+
+        for i in range(len(self.ranges)):
+            if len(self.ranges[i]) == 2:
+                self.ranges[i] += [0.5]
+            self.ranges[i][1] += self.ranges[i][2]
+
+        if "delta_x" in kwargs:
+            self.ranges[0][2] = kwargs.pop("delta_x")
+            self.ranges[0][1] += self.ranges[0][2] - 0.5
+        if "delta_y" in kwargs:
+            self.ranges[1][2] = kwargs.pop("delta_y")
+            self.ranges[1][1] += self.ranges[1][2] - 0.5
+
+        self.x_range, self.y_range, self.z_range = self.ranges
+
         super().__init__(
             func,
             color,
@@ -484,13 +575,6 @@ class ArrowVectorField(VectorField):
             colors,
             **kwargs,
         )
-        # Rounding min and max values to fit delta value
-        self.x_min = floor(x_min / delta_x) * delta_x
-        self.x_max = ceil(x_max / delta_x) * delta_x
-        self.y_min = floor(y_min / delta_y) * delta_y
-        self.y_max = ceil(y_max / delta_y) * delta_y
-        self.delta_x = delta_x
-        self.delta_y = delta_y
 
         self.length_func = length_func
         self.opacity = opacity
@@ -499,10 +583,11 @@ class ArrowVectorField(VectorField):
         self.vector_config = vector_config
         self.func = func
 
-        x_range = np.arange(self.x_min, self.x_max, self.delta_x)
-        y_range = np.arange(self.y_min, self.y_max, self.delta_y)
-        for x, y in it.product(x_range, y_range):
-            self.add(self.get_vector(x * RIGHT + y * UP))
+        x_range = np.arange(*self.x_range)
+        y_range = np.arange(*self.y_range)
+        z_range = np.arange(*self.z_range)
+        for x, y, z in it.product(x_range, y_range, z_range):
+            self.add(self.get_vector(x * RIGHT + y * UP + z * OUT))
         self.set_opacity(self.opacity)
 
     def get_vector(self, point: np.ndarray):
@@ -522,7 +607,7 @@ class ArrowVectorField(VectorField):
         """
         output = np.array(self.func(point))
         norm = np.linalg.norm(output)
-        if not norm == 0:
+        if norm != 0:
             output *= self.length_func(norm) / norm
         vect = Vector(output, **self.vector_config)
         vect.shift(point)
@@ -554,18 +639,15 @@ class StreamLines(VectorField):
         The value of the color_scheme function to be mapped to the last color in `colors`. Higher values also result in the last color of the gradient.
     colors
         The colors defining the color gradient of the vector field.
-    x_min
-        The minimum x value at which agends are spawned
-    x_max
-        The maximum x value at which agends are spawned
-    y_min
-        The minimum y value at which agends are spawned
-    y_max
-        The maximum y value at which agends are spawned
-    delta_x
-        The distance in x direction between two agents.
-    delta_y
-        The distance in y direction between two agents.
+    x_range
+        A sequence of x_min, x_max, delta_x
+    y_range
+        A sequence of y_min, y_max, delta_y
+    z_range
+        A sequence of z_min, z_max, delta_z
+    three_dimensions
+        Enables three_dimensions. Default set to False, automatically turns True if
+        z_range is not None.
     noise_factor
         The amount by which the starting position of each agent is altered along each axis. Defaults to :code:`delta_y / 2` if not defined.
     n_repeats
@@ -591,7 +673,7 @@ class StreamLines(VectorField):
 
         class BasicUsage(Scene):
             def construct(self):
-                func = lambda pos: ((pos[0]*UR+pos[1]*LEFT) - pos)/3
+                func = lambda pos: ((pos[0] * UR + pos[1] * LEFT) - pos) / 3
                 self.add(StreamLines(func))
 
     .. manim:: SpawningAndFlowingArea
@@ -599,20 +681,14 @@ class StreamLines(VectorField):
 
         class SpawningAndFlowingArea(Scene):
             def construct(self):
-                func = lambda pos: np.sin(pos[0])*UR+np.cos(pos[1])*LEFT+pos/5
+                func = lambda pos: np.sin(pos[0]) * UR + np.cos(pos[1]) * LEFT + pos / 5
                 stream_lines = StreamLines(
-                    func,
-                    x_min=-3, x_max=3, delta_x=0.2,
-                    y_min=-2, y_max=2, delta_y=0.2,
-                    padding=1
+                    func, x_range=[-3, 3, 0.2], y_range=[-2, 2, 0.2], padding=1
                 )
 
                 spawning_area = Rectangle(width=6, height=4)
                 flowing_area = Rectangle(width=8, height=6)
-                labels = [
-                    Tex("Spawning Area"),
-                    Tex("Flowing Area").shift(DOWN*2.5)
-                ]
+                labels = [Tex("Spawning Area"), Tex("Flowing Area").shift(DOWN * 2.5)]
                 for lbl in labels:
                     lbl.add_background_rectangle(opacity=0.6, buff=0.05)
 
@@ -620,6 +696,12 @@ class StreamLines(VectorField):
 
     """
 
+    @deprecated_params(
+        params="x_min, x_max, delta_x, y_min, y_max, delta_y",
+        since="v0.10.0",
+        until="v0.11.0",
+        message="Please use x_range and y_range instead.",
+    )
     def __init__(
         self,
         func: Callable[[np.ndarray], np.ndarray],
@@ -629,12 +711,10 @@ class StreamLines(VectorField):
         max_color_scheme_value: float = 2,
         colors: Sequence[Color] = DEFAULT_SCALAR_FIELD_COLORS,
         # Determining stream line starting positions:
-        x_min: float = -(config["frame_width"] + 1) / 2,
-        x_max: float = (config["frame_width"] + 1) / 2,
-        y_min: float = -(config["frame_height"] + 1) / 2,
-        y_max: float = (config["frame_height"] + 1) / 2,
-        delta_x: float = 0.5,
-        delta_y: float = 0.5,
+        x_range: Sequence[float] = None,
+        y_range: Sequence[float] = None,
+        z_range: Sequence[float] = None,
+        three_dimensions: bool = False,
         noise_factor: Optional[float] = None,
         n_repeats=1,
         # Determining how lines are drawn
@@ -647,6 +727,36 @@ class StreamLines(VectorField):
         opacity=1,
         **kwargs
     ):
+        self.x_range = x_range or [
+            kwargs.pop("x_min", None) or floor(-config["frame_width"] / 2),
+            kwargs.pop("x_max", None) or ceil(config["frame_width"] / 2),
+        ]
+        self.y_range = y_range or [
+            kwargs.pop("y_min", None) or floor(-config["frame_height"] / 2),
+            kwargs.pop("y_max", None) or ceil(config["frame_height"] / 2),
+        ]
+        self.ranges = [self.x_range, self.y_range]
+
+        if three_dimensions or z_range:
+            self.z_range = z_range or self.y_range.copy()
+            self.ranges += [self.z_range]
+        else:
+            self.ranges += [[0, 0]]
+
+        for i in range(len(self.ranges)):
+            if len(self.ranges[i]) == 2:
+                self.ranges[i] += [0.5]
+            self.ranges[i][1] += self.ranges[i][2]
+
+        if "delta_x" in kwargs:
+            self.ranges[0][2] = kwargs.pop("delta_x")
+            self.ranges[0][1] += self.ranges[0][2] - 0.5
+        if "delta_y" in kwargs:
+            self.ranges[1][2] = kwargs.pop("delta_y")
+            self.ranges[1][1] += self.ranges[1][2] - 0.5
+
+        self.x_range, self.y_range, self.z_range = self.ranges
+
         super().__init__(
             func,
             color,
@@ -656,13 +766,10 @@ class StreamLines(VectorField):
             colors,
             **kwargs,
         )
-        self.x_min = x_min
-        self.x_max = x_max
-        self.y_min = y_min
-        self.y_max = y_max
-        self.delta_x = delta_x
-        self.delta_y = delta_y
-        self.noise_factor = noise_factor if noise_factor is not None else delta_y / 2
+
+        self.noise_factor = (
+            noise_factor if noise_factor is not None else self.y_range[2] / 2
+        )
         self.n_repeats = n_repeats
         self.virtual_time = virtual_time
         self.max_anchors_per_line = max_anchors_per_line
@@ -675,45 +782,73 @@ class StreamLines(VectorField):
             [
                 (x - half_noise) * RIGHT
                 + (y - half_noise) * UP
+                + (z - half_noise) * OUT
                 + self.noise_factor * np.random.random(3)
                 for n in range(self.n_repeats)
-                for x in np.arange(self.x_min, self.x_max + self.delta_x, self.delta_x)
-                for y in np.arange(self.y_min, self.y_max + self.delta_y, self.delta_y)
-            ]
+                for x in np.arange(*self.x_range)
+                for y in np.arange(*self.y_range)
+                for z in np.arange(*self.z_range)
+            ],
         )
 
         def outside_box(p):
             return (
-                p[0] < self.x_min - self.padding
-                or p[0] > self.x_max + self.padding
-                or p[1] < self.y_min - self.padding
-                or p[1] > self.y_max + self.padding
+                p[0] < self.x_range[0] - self.padding
+                or p[0] > self.x_range[1] + self.padding - self.x_range[2]
+                or p[1] < self.y_range[0] - self.padding
+                or p[1] > self.y_range[1] + self.padding - self.y_range[2]
+                or p[2] < self.z_range[0] - self.padding
+                or p[2] > self.z_range[1] + self.padding - self.z_range[2]
             )
 
         max_steps = ceil(virtual_time / dt) + 1
         if not self.single_color:
             self.background_img = self.get_colored_background_image()
+            if config["renderer"] == "opengl":
+                self.values_to_rgbas = self.get_vectorized_rgba_gradient_function(
+                    min_color_scheme_value,
+                    max_color_scheme_value,
+                    colors,
+                )
         for point in start_points:
             points = [point]
-            for step in range(max_steps):
+            for _ in range(max_steps):
                 last_point = points[-1]
                 new_point = last_point + dt * func(last_point)
                 if outside_box(new_point):
                     break
                 points.append(new_point)
-            if step == 0:
+            step = max_steps
+            if not step:
                 continue
-            line = VMobject()
+            if config["renderer"] == "opengl":
+                line = OpenGLVMobject()
+            else:
+                line = VMobject()
             line.duration = step * dt
             step = max(1, int(len(points) / self.max_anchors_per_line))
             line.set_points_smoothly(points[::step])
             if self.single_color:
                 line.set_stroke(self.color)
             else:
-                # line.set_stroke([color_func(p) for p in line.get_anchors()])
-                # TODO use color_from_background_image
-                line.color_using_background_image(self.background_img)
-            line.set_stroke(width=self.stroke_width, opacity=opacity)
+                if config["renderer"] == "opengl":
+                    # scaled for compatibility with cairo
+                    line.set_stroke(width=self.stroke_width / 4.0)
+                    norms = np.array(
+                        [np.linalg.norm(self.func(point)) for point in line.points],
+                    )
+                    line.set_rgba_array_direct(
+                        self.values_to_rgbas(norms, opacity),
+                        name="stroke_rgba",
+                    )
+                else:
+                    if np.any(self.z_range != np.array([0, 0.5, 0.5])):
+                        line.set_stroke(
+                            [self.pos_to_color(p) for p in line.get_anchors()],
+                        )
+                    else:
+                        line.color_using_background_image(self.background_img)
+                    line.set_stroke(width=self.stroke_width, opacity=opacity)
             self.add(line)
         self.stream_lines = [*self.submobjects]
 
@@ -748,15 +883,17 @@ class StreamLines(VectorField):
 
             class StreamLineCreation(Scene):
                 def construct(self):
-                    func = lambda pos: (pos[0]*UR+pos[1]*LEFT) - pos
+                    func = lambda pos: (pos[0] * UR + pos[1] * LEFT) - pos
                     stream_lines = StreamLines(
                         func,
                         color=YELLOW,
-                        delta_x=1, delta_y=1, stroke_width=3,
-                        virtual_time=1,          # use shorter lines
-                        max_anchors_per_line=5,  #better performance with fewer anchors
+                        x_range=[-7, 7, 1],
+                        y_range=[-4, 4, 1],
+                        stroke_width=3,
+                        virtual_time=1,  # use shorter lines
+                        max_anchors_per_line=5,  # better performance with fewer anchors
                     )
-                    self.play(stream_lines.create()) # uses virtual_time as run_time
+                    self.play(stream_lines.create())  # uses virtual_time as run_time
                     self.wait()
 
         """
@@ -804,11 +941,8 @@ class StreamLines(VectorField):
 
             class ContinuousMotion(Scene):
                 def construct(self):
-                    func = lambda pos: np.sin(pos[0]/2)*UR+np.cos(pos[1]/2)*LEFT
-                    stream_lines = StreamLines(
-                        func, stroke_width=3,
-                        max_anchors_per_line=30
-                    )
+                    func = lambda pos: np.sin(pos[0] / 2) * UR + np.cos(pos[1] / 2) * LEFT
+                    stream_lines = StreamLines(func, stroke_width=3, max_anchors_per_line=30)
                     self.add(stream_lines)
                     stream_lines.start_animation(warm_up=False, flow_speed=1.5)
                     self.wait(stream_lines.virtual_time / stream_lines.flow_speed)
@@ -864,18 +998,12 @@ class StreamLines(VectorField):
 
             class EndAnimation(Scene):
                 def construct(self):
-                    func = lambda pos: np.sin(pos[0]/2)*UR+np.cos(pos[1]/2)*LEFT
+                    func = lambda pos: np.sin(pos[0] / 2) * UR + np.cos(pos[1] / 2) * LEFT
                     stream_lines = StreamLines(
-                        func, stroke_width=3,
-                        max_anchors_per_line=5,
-                        virtual_time=1, color=BLUE
+                        func, stroke_width=3, max_anchors_per_line=5, virtual_time=1, color=BLUE
                     )
                     self.add(stream_lines)
-                    stream_lines.start_animation(
-                        warm_up=False,
-                        flow_speed=1.5,
-                        time_width=0.5
-                    )
+                    stream_lines.start_animation(warm_up=False, flow_speed=1.5, time_width=0.5)
                     self.wait(1)
                     self.play(stream_lines.end_animation())
 
@@ -921,10 +1049,12 @@ class StreamLines(VectorField):
                 animations.append(
                     Succession(
                         UpdateFromAlphaFunc(
-                            line, hide_and_wait, run_time=-line.time / self.flow_speed
+                            line,
+                            hide_and_wait,
+                            run_time=-line.time / self.flow_speed,
                         ),
                         create,
-                    )
+                    ),
                 )
                 self.remove(line.anim.mobject)
                 line.anim.finish()
@@ -933,10 +1063,12 @@ class StreamLines(VectorField):
                 animations.append(
                     Succession(
                         UpdateFromAlphaFunc(
-                            line, finish_updater_cycle, run_time=remaining_time
+                            line,
+                            finish_updater_cycle,
+                            run_time=remaining_time,
                         ),
                         create,
-                    )
+                    ),
                 )
         return AnimationGroup(*animations)
 
