@@ -101,7 +101,10 @@ class CairoRenderer:
                 hash_current_animation = f"uncached_{self.num_plays:05}"
             else:
                 hash_current_animation = get_hash_from_play_call(
-                    scene, self.camera, scene.animations, scene.mobjects
+                    scene,
+                    self.camera,
+                    scene.animations,
+                    scene.mobjects,
                 )
                 if self.file_writer.is_already_cached(hash_current_animation):
                     logger.info(
@@ -230,7 +233,9 @@ class CairoRenderer:
         self.camera.get_image().show()
 
     def save_static_frame_data(
-        self, scene, static_mobjects: typing.Iterable[Mobject]
+        self,
+        scene,
+        static_mobjects: typing.Iterable[Mobject],
     ) -> typing.Iterable[Mobject]:
         """Compute and save the static frame, that will be reused at each frame to avoid to unecesseraly computer
         static mobjects.
@@ -264,13 +269,17 @@ class CairoRenderer:
         """
         if config["save_last_frame"]:
             self.skip_animations = True
-        if config["from_animation_number"]:
-            if self.num_plays < config["from_animation_number"]:
-                self.skip_animations = True
-        if config["upto_animation_number"]:
-            if self.num_plays > config["upto_animation_number"]:
-                self.skip_animations = True
-                raise EndSceneEarlyException()
+        if (
+            config["from_animation_number"]
+            and self.num_plays < config["from_animation_number"]
+        ):
+            self.skip_animations = True
+        if (
+            config["upto_animation_number"]
+            and self.num_plays > config["upto_animation_number"]
+        ):
+            self.skip_animations = True
+            raise EndSceneEarlyException()
 
     def scene_finished(self, scene):
         # If no animations in scene, render an image instead
