@@ -5,7 +5,7 @@ import moderngl
 import numpy as np
 from PIL import Image
 
-from manim import config
+from manim import config, logger
 from manim.renderer.cairo_renderer import handle_play_like_call
 from manim.utils.caching import handle_caching_play
 from manim.utils.color import color_to_rgba
@@ -57,12 +57,12 @@ class OpenGLCamera(OpenGLMobject):
         if self.orthographic:
             self.projection_matrix = opengl.orthographic_projection_matrix()
             self.unformatted_projection_matrix = opengl.orthographic_projection_matrix(
-                format=False
+                format=False,
             )
         else:
             self.projection_matrix = opengl.perspective_projection_matrix()
             self.unformatted_projection_matrix = opengl.perspective_projection_matrix(
-                format=False
+                format=False,
             )
 
         if frame_shape is None:
@@ -189,14 +189,14 @@ class OpenGLCamera(OpenGLMobject):
 
     def get_center(self):
         # Assumes first point is at the center
-        return self.get_points()[0]
+        return self.points[0]
 
     def get_width(self):
-        points = self.get_points()
+        points = self.points
         return points[2, 0] - points[1, 0]
 
     def get_height(self):
-        points = self.get_points()
+        points = self.points
         return points[4, 1] - points[3, 1]
 
     def get_focal_distance(self):
@@ -234,6 +234,8 @@ class OpenGLRenderer:
         # Initialize texture map.
         self.path_to_texture_id = {}
 
+        self._background_color = color_to_rgba(config["background_color"], 1.0)
+
     def init_scene(self, scene):
         self.partial_movie_files = []
         self.file_writer = self._file_writer_class(
@@ -242,7 +244,7 @@ class OpenGLRenderer:
         )
         self.scene = scene
         if not hasattr(self, "window"):
-            if config["preview"]:
+            if self.should_create_window():
                 from .opengl_renderer_window import Window
 
                 self.window = Window(self)
@@ -254,11 +256,13 @@ class OpenGLRenderer:
                     self.context = moderngl.create_context(standalone=True)
                 except Exception:
                     self.context = moderngl.create_context(
-                        standalone=True, backend="egl"
+                        standalone=True,
+                        backend="egl",
                     )
                 self.frame_buffer_object = self.get_frame_buffer_object(self.context, 0)
                 self.frame_buffer_object.use()
             self.context.enable(moderngl.BLEND)
+            self.context.wireframe = config["enable_wireframe"]
             self.context.blend_func = (
                 moderngl.SRC_ALPHA,
                 moderngl.ONE_MINUS_SRC_ALPHA,
@@ -266,6 +270,20 @@ class OpenGLRenderer:
                 moderngl.ONE,
             )
 
+    def should_create_window(self):
+        if config["force_window"]:
+            logger.warning(
+                "'--force_window' is enabled, this is intended for debugging purposes "
+                "and may impact performance if used when outputting files",
+            )
+            return True
+        return (
+            config["preview"]
+            and not config["save_last_frame"]
+            and not config["format"]
+            and not config["write_to_movie"]
+        )
+
     def get_pixel_shape(self):
         if hasattr(self, "frame_buffer_object"):
             return self.frame_buffer_object.viewport[2:4]
@@ -313,7 +331,8 @@ class OpenGLRenderer:
 
             # Set uniforms.
             for name, value in it.chain(
-                shader_wrapper.uniforms.items(), self.perspective_uniforms.items()
+                shader_wrapper.uniforms.items(),
+                self.perspective_uniforms.items(),
             ):
                 try:
                     shader.set_uniform(name, value)
@@ -322,7 +341,8 @@ class OpenGLRenderer:
             try:
                 shader.set_uniform("u_view_matrix", self.scene.camera.get_view_matrix())
                 shader.set_uniform(
-                    "u_projection_matrix", self.scene.camera.projection_matrix
+                    "u_projection_matrix",
+                    self.scene.camera.projection_matrix,
                 )
             except KeyError:
                 pass
@@ -366,13 +386,17 @@ class OpenGLRenderer:
         the number of animations that need to be played, and
         raises an EndSceneEarlyException if they don't correspond.
         """
-        if config["from_animation_number"]:
-            if self.num_plays < config["from_animation_number"]:
-                self.skip_animations = True
-        if config["upto_animation_number"]:
-            if self.num_plays > config["upto_animation_number"]:
-                self.skip_animations = True
-                raise EndSceneEarlyException()
+        if (
+            config["from_animation_number"]
+            and self.num_plays < config["from_animation_number"]
+        ):
+            self.skip_animations = True
+        if (
+            config["upto_animation_number"]
+            and self.num_plays > config["upto_animation_number"]
+        ):
+            self.skip_animations = True
+            raise EndSceneEarlyException()
 
     @handle_caching_play
     @handle_play_like_call
@@ -383,8 +407,7 @@ class OpenGLRenderer:
             scene.play_internal()
 
     def clear_screen(self):
-        window_background_color = color_to_rgba(config["background_color"])
-        self.frame_buffer_object.clear(*window_background_color)
+        self.frame_buffer_object.clear(*self.background_color)
         self.window.swap_buffers()
 
     def render(self, scene, frame_offset, moving_mobjects):
@@ -393,8 +416,7 @@ class OpenGLRenderer:
         if self.skip_animations:
             return
 
-        if config["write_to_movie"]:
-            self.file_writer.write_frame(self)
+        self.file_writer.write_frame(self)
 
         if self.window is not None:
             self.window.swap_buffers()
@@ -403,8 +425,7 @@ class OpenGLRenderer:
                 self.window.swap_buffers()
 
     def update_frame(self, scene):
-        window_background_color = color_to_rgba(config["background_color"])
-        self.frame_buffer_object.clear(*window_background_color)
+        self.frame_buffer_object.clear(*self.background_color)
         self.refresh_perspective_uniforms(scene.camera)
 
         for mobject in scene.mobjects:
@@ -418,7 +439,11 @@ class OpenGLRenderer:
         self.animation_elapsed_time = time.time() - self.animation_start_time
 
     def scene_finished(self, scene):
-        if config["save_last_frame"]:
+        # When num_plays is 0, no images have been output, so output a single
+        # image in this case
+        if config["save_last_frame"] or (
+            config["format"] == "png" and self.num_plays == 0
+        ):
             self.update_frame(scene)
             self.file_writer.save_final_image(self.get_image())
         self.file_writer.finish()
@@ -436,10 +461,11 @@ class OpenGLRenderer:
         PIL.Image
             The PIL image of the array.
         """
+        raw_buffer_data = self.get_raw_frame_buffer_object_data()
         image = Image.frombytes(
             "RGBA",
             self.get_pixel_shape(),
-            self.context.fbo.read(self.get_pixel_shape(), components=4),
+            raw_buffer_data,
             "raw",
             "RGBA",
             0,
@@ -461,7 +487,8 @@ class OpenGLRenderer:
                 samples=samples,
             ),
             depth_attachment=context.depth_renderbuffer(
-                (pixel_width, pixel_height), samples=samples
+                (pixel_width, pixel_height),
+                samples=samples,
             ),
         )
 
@@ -484,7 +511,8 @@ class OpenGLRenderer:
     def get_frame(self):
         # get current pixel values as numpy data in order to test output
         raw = self.get_raw_frame_buffer_object_data(dtype="f1")
-        result_dimensions = (config["pixel_height"], config["pixel_width"], 4)
+        pixel_shape = self.get_pixel_shape()
+        result_dimensions = (pixel_shape[1], pixel_shape[0], 4)
         np_buf = np.frombuffer(raw, dtype="uint8").reshape(result_dimensions)
         np_buf = np.flipud(np_buf)
         return np_buf
@@ -503,3 +531,11 @@ class OpenGLRenderer:
             # Only scale wrt one axis
             scale = fh / ph
             return fc + scale * np.array([(px - pw / 2), (py - ph / 2), 0])
+
+    @property
+    def background_color(self):
+        return self._background_color
+
+    @background_color.setter
+    def background_color(self, value):
+        self._background_color = color_to_rgba(value, 1.0)
