@@ -71,7 +71,7 @@ class ShaderWrapper:
                 self.vert_data is not None,
                 self.program_code["vertex_shader"] is not None,
                 self.program_code["fragment_shader"] is not None,
-            ]
+            ],
         )
 
     def get_id(self):
@@ -92,7 +92,7 @@ class ShaderWrapper:
                     self.depth_test,
                     self.render_primitive,
                 ],
-            )
+            ),
         )
 
     def refresh_id(self):
@@ -104,13 +104,13 @@ class ShaderWrapper:
             "".join(
                 self.program_code[f"{name}_shader"] or ""
                 for name in ("vertex", "geometry", "fragment")
-            )
+            ),
         )
 
     def init_program_code(self):
         def get_code(name):
             return get_shader_code_from_file(
-                os.path.join(self.shader_folder, f"{name}.glsl")
+                os.path.join(self.shader_folder, f"{name}.glsl"),
             )
 
         self.program_code = {
@@ -124,7 +124,7 @@ class ShaderWrapper:
 
     def replace_code(self, old, new):
         code_map = self.program_code
-        for (name, code) in code_map.items():
+        for (name, _code) in code_map.items():
             if code_map[name] is None:
                 continue
             code_map[name] = re.sub(old, new, code_map[name])
@@ -146,7 +146,7 @@ class ShaderWrapper:
             self.vert_data = np.hstack(data_list)
         else:
             self.vert_data = np.hstack(
-                [self.vert_data, *(sw.vert_data for sw in shader_wrappers)]
+                [self.vert_data, *(sw.vert_data for sw in shader_wrappers)],
             )
         return self
 
@@ -177,11 +177,13 @@ def get_shader_code_from_file(filename):
     # passing to ctx.program for compiling
     # Replace "#INSERT " lines with relevant code
     insertions = re.findall(
-        r"^#include ../include/.*\.glsl$", result, flags=re.MULTILINE
+        r"^#include ../include/.*\.glsl$",
+        result,
+        flags=re.MULTILINE,
     )
     for line in insertions:
         inserted_code = get_shader_code_from_file(
-            os.path.join("inserts", line.replace("#include ../include/", ""))
+            os.path.join("include", line.replace("#include ../include/", "")),
         )
         result = result.replace(line, inserted_code)
     filename_to_code_map[filename] = result
