@@ -1,15 +1,12 @@
 """Debugging utilities."""
 
 
-__all__ = ["print_family", "index_labels", "get_submobject_index_labels"]
+__all__ = ["print_family", "index_labels"]
 
 
-from os import replace
-
 from ..mobject.numbers import Integer
 from ..mobject.types.vectorized_mobject import VGroup
 from .color import BLACK
-from .deprecation import deprecated
 
 
 def print_family(mobject, n_tabs=0):
@@ -28,8 +25,3 @@ def index_labels(mobject, label_height=0.15):
         label.set_stroke(BLACK, 5, background=True)
         labels.add(label)
     return labels
-
-
-@deprecated(until="v0.6.0", replacement="index_labels")
-def get_submobject_index_labels(mobject, label_height=0.15):
-    return index_labels(mobject, label_height)
