@@ -11,7 +11,11 @@ def matrix_to_shader_input(matrix):
 
 
 def orthographic_projection_matrix(
-    width=None, height=None, near=1, far=depth + 1, format=True
+    width=None,
+    height=None,
+    near=1,
+    far=depth + 1,
+    format=True,
 ):
     if width is None:
         width = config["frame_width"]
@@ -23,7 +27,7 @@ def orthographic_projection_matrix(
             [0, 2 / height, 0, 0],
             [0, 0, -2 / (far - near), -(far + near) / (far - near)],
             [0, 0, 0, 1],
-        ]
+        ],
     )
     if format:
         return matrix_to_shader_input(projection_matrix)
@@ -42,7 +46,7 @@ def perspective_projection_matrix(width=None, height=None, near=2, far=50, forma
             [0, 2 * near / height, 0, 0],
             [0, 0, (far + near) / (near - far), (2 * far * near) / (near - far)],
             [0, 0, -1, 0],
-        ]
+        ],
     )
     if format:
         return matrix_to_shader_input(projection_matrix)
@@ -57,7 +61,7 @@ def translation_matrix(x=0, y=0, z=0):
             [0, 1, 0, y],
             [0, 0, 1, z],
             [0, 0, 0, 1],
-        ]
+        ],
     )
 
 
@@ -68,7 +72,7 @@ def x_rotation_matrix(x=0):
             [0, np.cos(x), -np.sin(x), 0],
             [0, np.sin(x), np.cos(x), 0],
             [0, 0, 0, 1],
-        ]
+        ],
     )
 
 
@@ -79,7 +83,7 @@ def y_rotation_matrix(y=0):
             [0, 1, 0, 0],
             [-np.sin(y), 0, np.cos(y), 0],
             [0, 0, 0, 1],
-        ]
+        ],
     )
 
 
@@ -90,7 +94,7 @@ def z_rotation_matrix(z=0):
             [np.sin(z), np.cos(z), 0, 0],
             [0, 0, 1, 0],
             [0, 0, 0, 1],
-        ]
+        ],
     )
 
 
@@ -107,7 +111,8 @@ def rotate_in_place_matrix(initial_position, x=0, y=0, z=0):
 
 def rotation_matrix(x=0, y=0, z=0):
     return np.matmul(
-        np.matmul(x_rotation_matrix(x), y_rotation_matrix(y)), z_rotation_matrix(z)
+        np.matmul(x_rotation_matrix(x), y_rotation_matrix(y)),
+        z_rotation_matrix(z),
     )
 
 
@@ -118,7 +123,7 @@ def scale_matrix(scale_factor=1):
             [0, scale_factor, 0, 0],
             [0, 0, scale_factor, 0],
             [0, 0, 0, 1],
-        ]
+        ],
     )
 
 
