@@ -27,6 +27,8 @@ __all__ = [
     "get_winding_number",
     "cross2d",
     "earclip_triangulation",
+    "cartesian_to_spherical",
+    "spherical_to_cartesian",
     "perpendicular_bisector",
 ]
 
@@ -90,12 +92,14 @@ def quaternion_mult(
                 w1 * x2 + x1 * w2 + y1 * z2 - z1 * y2,
                 w1 * y2 + y1 * w2 + z1 * x2 - x1 * z2,
                 w1 * z2 + z1 * w2 + x1 * y2 - y1 * x2,
-            ]
+            ],
         )
 
 
 def quaternion_from_angle_axis(
-    angle: float, axis: np.ndarray, axis_normalized: bool = False
+    angle: float,
+    axis: np.ndarray,
+    axis_normalized: bool = False,
 ) -> List[float]:
     """Gets a quaternion from an angle and an axis.
     For more information, check `this Wikipedia page
@@ -252,7 +256,9 @@ def rotation_matrix_transpose(angle: float, axis: np.ndarray) -> np.ndarray:
 
 
 def rotation_matrix(
-    angle: float, axis: np.ndarray, homogeneous: bool = False
+    angle: float,
+    axis: np.ndarray,
+    homogeneous: bool = False,
 ) -> np.ndarray:
     """
     Rotation in R^3 about a specified axis of rotation.
@@ -308,7 +314,7 @@ def z_to_vector(vector: np.ndarray) -> np.ndarray:
     else:
         theta = 0
     phi_down = np.array(
-        [[np.cos(phi), 0, np.sin(phi)], [0, 1, 0], [-np.sin(phi), 0, np.cos(phi)]]
+        [[np.cos(phi), 0, np.sin(phi)], [0, 1, 0], [-np.sin(phi), 0, np.cos(phi)]],
     )
     return np.dot(rotation_about_z(theta), phi_down)
 
@@ -533,7 +539,8 @@ def center_of_mass(points: Sequence[float]) -> np.ndarray:
 
 
 def midpoint(
-    point1: Sequence[float], point2: Sequence[float]
+    point1: Sequence[float],
+    point2: Sequence[float],
 ) -> Union[float, np.ndarray]:
     """Gets the midpoint of two points.
 
@@ -695,7 +702,7 @@ def earclip_triangulation(verts: np.ndarray, ring_ends: list) -> list:
                     # used to draw some connection
                     lambda i: i not in loop_connections,
                     it.chain(*ring_group),
-                )
+                ),
             )
             for ring_group in (attached_rings, detached_rings)
         )
@@ -747,28 +754,52 @@ def earclip_triangulation(verts: np.ndarray, ring_ends: list) -> list:
     return [indices[mi] for mi in meta_indices]
 
 
-def cartesian_to_spherical(vec):
+def cartesian_to_spherical(vec: Sequence[float]) -> np.ndarray:
+    """Returns an array of numbers corresponding to each
+    polar coordinate value (distance, phi, theta).
+
+    Parameters
+    ----------
+    vec
+        A numpy array ``[x, y, z]``.
+    """
     norm = np.linalg.norm(vec)
     if norm == 0:
         return 0, 0, 0
     r = norm
-    theta = np.arccos(vec[2] / r)
-    phi = np.arctan2(vec[1], vec[0])
-    return r, theta, phi
+    phi = np.arccos(vec[2] / r)
+    theta = np.arctan2(vec[1], vec[0])
+    return np.array([r, phi, theta])
 
 
-def spherical_to_cartesian(r, theta, phi):
+def spherical_to_cartesian(spherical: Sequence[float]) -> np.ndarray:
+    """Returns a numpy array ``[x, y, z]`` based on the spherical
+    coordinates given.
+
+    Parameters
+    ----------
+    spherical
+        A list of three floats that correspond to the following:
+
+        r - The distance between the point and the origin.
+
+        theta - The azimuthal angle of the point to the positive x-axis.
+
+        phi - The vertical angle of the point to the positive z-axis.
+    """
+    r, theta, phi = spherical
     return np.array(
         [
-            r * np.cos(phi) * np.sin(theta),
-            r * np.sin(phi) * np.sin(theta),
-            r * np.cos(theta),
-        ]
+            r * np.cos(theta) * np.sin(phi),
+            r * np.sin(theta) * np.sin(phi),
+            r * np.cos(phi),
+        ],
     )
 
 
 def perpendicular_bisector(
-    line: Sequence[np.ndarray], norm_vector=OUT
+    line: Sequence[np.ndarray],
+    norm_vector=OUT,
 ) -> Sequence[np.ndarray]:
     """Returns a list of two points that correspond
     to the ends of the perpendicular bisector of the
